export const kangxiToCjk = new Map<string, string>()
export const cjkToKangxi = new Map<string, string>()
export const supplementToCjk = new Map<string, string>()
export const cjkToSupplement = new Map<string, string>()

function initMaps (
  kangxiMappings: Array<{ kangxi: string, cjk: string }>,
  supplementMappings: Array<{ supplement: string, cjk: string }>
): void {
  for (const { kangxi, cjk } of kangxiMappings) {
    kangxiToCjk.set(kangxi, cjk)
    cjkToKangxi.set(cjk, kangxi)
  }
  for (const { supplement, cjk } of supplementMappings) {
    supplementToCjk.set(supplement, cjk)
    cjkToSupplement.set(cjk, supplement)
  }
}

initMaps(
  [
    { kangxi: '⼀', cjk: '一' },
    { kangxi: '⼁', cjk: '丨' },
    { kangxi: '⼂', cjk: '丶' },
    { kangxi: '⼃', cjk: '丿' },
    { kangxi: '⼄', cjk: '乙' },
    { kangxi: '⼅', cjk: '亅' },
    { kangxi: '⼆', cjk: '二' },
    { kangxi: '⼇', cjk: '亠' },
    { kangxi: '⼈', cjk: '人' },
    { kangxi: '⼉', cjk: '儿' },
    { kangxi: '⼊', cjk: '入' },
    { kangxi: '⼋', cjk: '八' },
    { kangxi: '⼌', cjk: '冂' },
    { kangxi: '⼍', cjk: '冖' },
    { kangxi: '⼎', cjk: '冫' },
    { kangxi: '⼏', cjk: '几' },
    { kangxi: '⼐', cjk: '凵' },
    { kangxi: '⼑', cjk: '刀' },
    { kangxi: '⼒', cjk: '力' },
    { kangxi: '⼓', cjk: '勹' },
    { kangxi: '⼔', cjk: '匕' },
    { kangxi: '⼕', cjk: '匚' },
    { kangxi: '⼖', cjk: '匸' },
    { kangxi: '⼗', cjk: '十' },
    { kangxi: '⼘', cjk: '卜' },
    { kangxi: '⼙', cjk: '卩' },
    { kangxi: '⼚', cjk: '厂' },
    { kangxi: '⼛', cjk: '厶' },
    { kangxi: '⼜', cjk: '又' },
    { kangxi: '⼝', cjk: '口' },
    { kangxi: '⼞', cjk: '囗' },
    { kangxi: '⼟', cjk: '土' },
    { kangxi: '⼠', cjk: '士' },
    { kangxi: '⼡', cjk: '夂' },
    { kangxi: '⼢', cjk: '夊' },
    { kangxi: '⼣', cjk: '夕' },
    { kangxi: '⼤', cjk: '大' },
    { kangxi: '⼥', cjk: '女' },
    { kangxi: '⼦', cjk: '子' },
    { kangxi: '⼧', cjk: '宀' },
    { kangxi: '⼨', cjk: '寸' },
    { kangxi: '⼩', cjk: '小' },
    { kangxi: '⼪', cjk: '尢' },
    { kangxi: '⼫', cjk: '尸' },
    { kangxi: '⼬', cjk: '屮' },
    { kangxi: '⼭', cjk: '山' },
    { kangxi: '⼮', cjk: '巛' },
    { kangxi: '⼯', cjk: '工' },
    { kangxi: '⼰', cjk: '己' },
    { kangxi: '⼱', cjk: '巾' },
    { kangxi: '⼲', cjk: '干' },
    { kangxi: '⼳', cjk: '幺' },
    { kangxi: '⼴', cjk: '广' },
    { kangxi: '⼵', cjk: '廴' },
    { kangxi: '⼶', cjk: '廾' },
    { kangxi: '⼷', cjk: '弋' },
    { kangxi: '⼸', cjk: '弓' },
    { kangxi: '⼹', cjk: '彐' },
    { kangxi: '⼺', cjk: '彡' },
    { kangxi: '⼻', cjk: '彳' },
    { kangxi: '⼼', cjk: '心' },
    { kangxi: '⼽', cjk: '戈' },
    { kangxi: '⼾', cjk: '戶' },
    { kangxi: '⼿', cjk: '手' },
    { kangxi: '⽀', cjk: '支' },
    { kangxi: '⽁', cjk: '攴' },
    { kangxi: '⽂', cjk: '文' },
    { kangxi: '⽃', cjk: '斗' },
    { kangxi: '⽄', cjk: '斤' },
    { kangxi: '⽅', cjk: '方' },
    { kangxi: '⽆', cjk: '无' },
    { kangxi: '⽇', cjk: '日' },
    { kangxi: '⽈', cjk: '曰' },
    { kangxi: '⽉', cjk: '月' },
    { kangxi: '⽊', cjk: '木' },
    { kangxi: '⽋', cjk: '欠' },
    { kangxi: '⽌', cjk: '止' },
    { kangxi: '⽍', cjk: '歹' },
    { kangxi: '⽎', cjk: '殳' },
    { kangxi: '⽏', cjk: '毋' },
    { kangxi: '⽐', cjk: '比' },
    { kangxi: '⽑', cjk: '毛' },
    { kangxi: '⽒', cjk: '氏' },
    { kangxi: '⽓', cjk: '气' },
    { kangxi: '⽔', cjk: '水' },
    { kangxi: '⽕', cjk: '火' },
    { kangxi: '⽖', cjk: '爪' },
    { kangxi: '⽗', cjk: '父' },
    { kangxi: '⽘', cjk: '爻' },
    { kangxi: '⽙', cjk: '爿' },
    { kangxi: '⽚', cjk: '片' },
    { kangxi: '⽛', cjk: '牙' },
    { kangxi: '⽜', cjk: '牛' },
    { kangxi: '⽝', cjk: '犬' },
    { kangxi: '⽞', cjk: '玄' },
    { kangxi: '⽟', cjk: '玉' },
    { kangxi: '⽠', cjk: '瓜' },
    { kangxi: '⽡', cjk: '瓦' },
    { kangxi: '⽢', cjk: '甘' },
    { kangxi: '⽣', cjk: '生' },
    { kangxi: '⽤', cjk: '用' },
    { kangxi: '⽥', cjk: '田' },
    { kangxi: '⽦', cjk: '疋' },
    { kangxi: '⽧', cjk: '疒' },
    { kangxi: '⽨', cjk: '癶' },
    { kangxi: '⽩', cjk: '白' },
    { kangxi: '⽪', cjk: '皮' },
    { kangxi: '⽫', cjk: '皿' },
    { kangxi: '⽬', cjk: '目' },
    { kangxi: '⽭', cjk: '矛' },
    { kangxi: '⽮', cjk: '矢' },
    { kangxi: '⽯', cjk: '石' },
    { kangxi: '⽰', cjk: '示' },
    { kangxi: '⽱', cjk: '禸' },
    { kangxi: '⽲', cjk: '禾' },
    { kangxi: '⽳', cjk: '穴' },
    { kangxi: '⽴', cjk: '立' },
    { kangxi: '⽵', cjk: '竹' },
    { kangxi: '⽶', cjk: '米' },
    { kangxi: '⽷', cjk: '糸' },
    { kangxi: '⽸', cjk: '缶' },
    { kangxi: '⽹', cjk: '网' },
    { kangxi: '⽺', cjk: '羊' },
    { kangxi: '⽻', cjk: '羽' },
    { kangxi: '⽼', cjk: '老' },
    { kangxi: '⽽', cjk: '而' },
    { kangxi: '⽾', cjk: '耒' },
    { kangxi: '⽿', cjk: '耳' },
    { kangxi: '⾀', cjk: '聿' },
    { kangxi: '⾁', cjk: '肉' },
    { kangxi: '⾂', cjk: '臣' },
    { kangxi: '⾃', cjk: '自' },
    { kangxi: '⾄', cjk: '至' },
    { kangxi: '⾅', cjk: '臼' },
    { kangxi: '⾆', cjk: '舌' },
    { kangxi: '⾇', cjk: '舛' },
    { kangxi: '⾈', cjk: '舟' },
    { kangxi: '⾉', cjk: '艮' },
    { kangxi: '⾊', cjk: '色' },
    { kangxi: '⾋', cjk: '艸' },
    { kangxi: '⾌', cjk: '虍' },
    { kangxi: '⾍', cjk: '虫' },
    { kangxi: '⾎', cjk: '血' },
    { kangxi: '⾏', cjk: '行' },
    { kangxi: '⾐', cjk: '衣' },
    { kangxi: '⾑', cjk: '襾' },
    { kangxi: '⾒', cjk: '見' },
    { kangxi: '⾓', cjk: '角' },
    { kangxi: '⾔', cjk: '言' },
    { kangxi: '⾕', cjk: '谷' },
    { kangxi: '⾖', cjk: '豆' },
    { kangxi: '⾗', cjk: '豕' },
    { kangxi: '⾘', cjk: '豸' },
    { kangxi: '⾙', cjk: '貝' },
    { kangxi: '⾚', cjk: '赤' },
    { kangxi: '⾛', cjk: '走' },
    { kangxi: '⾜', cjk: '足' },
    { kangxi: '⾝', cjk: '身' },
    { kangxi: '⾞', cjk: '車' },
    { kangxi: '⾟', cjk: '辛' },
    { kangxi: '⾠', cjk: '辰' },
    { kangxi: '⾡', cjk: '辵' },
    { kangxi: '⾢', cjk: '邑' },
    { kangxi: '⾣', cjk: '酉' },
    { kangxi: '⾤', cjk: '釆' },
    { kangxi: '⾥', cjk: '里' },
    { kangxi: '⾦', cjk: '金' },
    { kangxi: '⾧', cjk: '長' },
    { kangxi: '⾨', cjk: '門' },
    { kangxi: '⾩', cjk: '阜' },
    { kangxi: '⾪', cjk: '隶' },
    { kangxi: '⾫', cjk: '隹' },
    { kangxi: '⾬', cjk: '雨' },
    { kangxi: '⾭', cjk: '靑' },
    { kangxi: '⾮', cjk: '非' },
    { kangxi: '⾯', cjk: '面' },
    { kangxi: '⾰', cjk: '革' },
    { kangxi: '⾱', cjk: '韋' },
    { kangxi: '⾲', cjk: '韭' },
    { kangxi: '⾳', cjk: '音' },
    { kangxi: '⾴', cjk: '頁' },
    { kangxi: '⾵', cjk: '風' },
    { kangxi: '⾶', cjk: '飛' },
    { kangxi: '⾷', cjk: '食' },
    { kangxi: '⾸', cjk: '首' },
    { kangxi: '⾹', cjk: '香' },
    { kangxi: '⾺', cjk: '馬' },
    { kangxi: '⾻', cjk: '骨' },
    { kangxi: '⾼', cjk: '高' },
    { kangxi: '⾽', cjk: '髟' },
    { kangxi: '⾾', cjk: '鬥' },
    { kangxi: '⾿', cjk: '鬯' },
    { kangxi: '⿀', cjk: '鬲' },
    { kangxi: '⿁', cjk: '鬼' },
    { kangxi: '⿂', cjk: '魚' },
    { kangxi: '⿃', cjk: '鳥' },
    { kangxi: '⿄', cjk: '鹵' },
    { kangxi: '⿅', cjk: '鹿' },
    { kangxi: '⿆', cjk: '麥' },
    { kangxi: '⿇', cjk: '麻' },
    { kangxi: '⿈', cjk: '黃' },
    { kangxi: '⿉', cjk: '黍' },
    { kangxi: '⿊', cjk: '黑' },
    { kangxi: '⿋', cjk: '黹' },
    { kangxi: '⿌', cjk: '黽' },
    { kangxi: '⿍', cjk: '鼎' },
    { kangxi: '⿎', cjk: '鼓' },
    { kangxi: '⿏', cjk: '鼠' },
    { kangxi: '⿐', cjk: '鼻' },
    { kangxi: '⿑', cjk: '齊' },
    { kangxi: '⿒', cjk: '齒' },
    { kangxi: '⿓', cjk: '龍' },
    { kangxi: '⿔', cjk: '龜' },
    { kangxi: '⿕', cjk: '龠' }
  ],
  [
    { supplement: '⺀', cjk: '二' },
    { supplement: '⺁', cjk: '厂' },
    { supplement: '⺂', cjk: '乛' },
    { supplement: '⺃', cjk: '乚' },
    { supplement: '⺄', cjk: '乙' },
    { supplement: '⺅', cjk: '亻' },
    { supplement: '⺆', cjk: '冂' },
    { supplement: '⺇', cjk: '几' },
    { supplement: '⺈', cjk: '刀' },
    { supplement: '⺉', cjk: '刂' },
    { supplement: '⺊', cjk: '卜' },
    { supplement: '⺋', cjk: '㔾' },
    { supplement: '⺌', cjk: '小' },
    { supplement: '⺍', cjk: '小' },
    { supplement: '⺎', cjk: '尢' },
    { supplement: '⺏', cjk: '尣' },
    { supplement: '⺐', cjk: '尢' },
    { supplement: '⺑', cjk: '尣' },
    { supplement: '⺒', cjk: '巳' },
    { supplement: '⺓', cjk: '幺' },
    { supplement: '⺔', cjk: '彑' },
    { supplement: '⺕', cjk: '彐' },
    { supplement: '⺖', cjk: '忄' },
    { supplement: '⺗', cjk: '心' },
    { supplement: '⺘', cjk: '扌' },
    { supplement: '⺙', cjk: '攵' },
    { supplement: '⺛', cjk: '旡' },
    { supplement: '⺜', cjk: '日' },
    { supplement: '⺝', cjk: '月' },
    { supplement: '⺞', cjk: '歺' },
    { supplement: '⺟', cjk: '母' },
    { supplement: '⺠', cjk: '民' },
    { supplement: '⺡', cjk: '氵' },
    { supplement: '⺢', cjk: '氺' },
    { supplement: '⺣', cjk: '灬' },
    { supplement: '⺤', cjk: '爫' },
    { supplement: '⺥', cjk: '爪' },
    { supplement: '⺦', cjk: '丬' },
    { supplement: '⺧', cjk: '牛' },
    { supplement: '⺨', cjk: '犭' },
    { supplement: '⺩', cjk: '王' },
    { supplement: '⺪', cjk: '疋' },
    { supplement: '⺫', cjk: '罒' },
    { supplement: '⺬', cjk: '示' },
    { supplement: '⺭', cjk: '礻' },
    { supplement: '⺮', cjk: '竹' },
    { supplement: '⺯', cjk: '糹' },
    { supplement: '⺰', cjk: '纟' },
    { supplement: '⺱', cjk: '罓' },
    { supplement: '⺲', cjk: '罒' },
    { supplement: '⺳', cjk: '网' },
    { supplement: '⺴', cjk: '网' },
    { supplement: '⺵', cjk: '𦉫' },
    { supplement: '⺶', cjk: '羊' },
    { supplement: '⺷', cjk: '羊' },
    { supplement: '⺸', cjk: '羋' },
    { supplement: '⺹', cjk: '耂' },
    { supplement: '⺺', cjk: '肀' },
    { supplement: '⺻', cjk: '聿' },
    { supplement: '⺼', cjk: '肉' },
    { supplement: '⺽', cjk: '臼' },
    { supplement: '⺾', cjk: '艹' },
    { supplement: '⺿', cjk: '艹' },
    { supplement: '⻀', cjk: '艹' },
    { supplement: '⻁', cjk: '虎' },
    { supplement: '⻂', cjk: '衤' },
    { supplement: '⻃', cjk: '覀' },
    { supplement: '⻄', cjk: '西' },
    { supplement: '⻅', cjk: '见' },
    { supplement: '⻆', cjk: '角' },
    { supplement: '⻇', cjk: '𧢲' },
    { supplement: '⻈', cjk: '讠' },
    { supplement: '⻉', cjk: '贝' },
    { supplement: '⻊', cjk: '足' },
    { supplement: '⻋', cjk: '车' },
    { supplement: '⻌', cjk: '辶' },
    { supplement: '⻍', cjk: '辶' },
    { supplement: '⻎', cjk: '辶' },
    { supplement: '⻏', cjk: '→' },
    { supplement: '⻐', cjk: '钅' },
    { supplement: '⻑', cjk: '長' },
    { supplement: '⻒', cjk: '镸' },
    { supplement: '⻓', cjk: '长' },
    { supplement: '⻔', cjk: '门' },
    { supplement: '⻕', cjk: '阜' },
    { supplement: '⻖', cjk: '阝' },
    { supplement: '⻗', cjk: '雨' },
    { supplement: '⻘', cjk: '青' },
    { supplement: '⻙', cjk: '韦' },
    { supplement: '⻚', cjk: '页' },
    { supplement: '⻛', cjk: '风' },
    { supplement: '⻜', cjk: '飞' },
    { supplement: '⻝', cjk: '食' },
    { supplement: '⻞', cjk: '𩙿' },
    { supplement: '⻟', cjk: '飠' },
    { supplement: '⻠', cjk: '饣' },
    { supplement: '⻡', cjk: '𩠐' },
    { supplement: '⻢', cjk: '马' },
    { supplement: '⻣', cjk: '骨' },
    { supplement: '⻤', cjk: '鬼' },
    { supplement: '⻥', cjk: '鱼' },
    { supplement: '⻦', cjk: '鸟' },
    { supplement: '⻧', cjk: '鹵' },
    { supplement: '⻨', cjk: '麦' },
    { supplement: '⻩', cjk: '黄' },
    { supplement: '⻪', cjk: '黾' },
    { supplement: '⻫', cjk: '斉' },
    { supplement: '⻬', cjk: '齐' },
    { supplement: '⻭', cjk: '歯' },
    { supplement: '⻮', cjk: '齿' },
    { supplement: '⻯', cjk: '竜' },
    { supplement: '⻰', cjk: '龙' },
    { supplement: '⻱', cjk: '龜' },
    { supplement: '⻲', cjk: '亀' },
    { supplement: '⻳', cjk: '龟' }
  ]
)
